# FASPEX 4.4.1 PATCH Level 3
**Operating Systems:** Linux and Windows
**Date:** 04/23/2020

This patch includes the following fixes:

### Patch Level 3 Fixes
| Jira Issue | Description                                                                                                                   |
| ---------- |:----------------------------------------------------------------------------------------------------------------------------- |
| FASPX-1789 | Dropbox invitations do not allow users to apply EAR when dropbox or global settings are set to **optional**. Read the notes below to check if your situation requires follow-up actions.|
| FASPX-1783 | The pagination for `/api/users` returns 404 instead of an empty array when `page_num` exceeds page count.                     |

### Notes related to FASPX-1789:

#### THE PROBLEM

Faspex 4.4 introduced the ability to configure, on a per-invitation basis, whether invited submitters are required to upload using encryption-at-rest (EAR). This per-invitation setting overrules dropbox and global settings. Users configure this setting when creating a new invitation. 

Upgrading to Faspex 4.4 sets the EAR requirement of pre-existing invitation to the default of **no**. Since EAR settings are only configurable when creating an invitation, pre-existing invitations do not allow submitters to use EAR when the dropbox or global settings are **optional**.

#### PATCH BEHAVIOR

Applying Patch Level 3 changes the default EAR requirement from **no** to unset. The patch also updates all invitations with EAR requirements set to **no** to inherit settings from the dropbox or global level by leaving the setting unset. Invitations with EAR requirements set to **yes** or **optional** are unaffected. When dropbox or global settings are **optional**, new invitations follow the EAR requirement set when the invitation was created. Otherwise, invitations follow relevant dropbox and global settings.

#### THE FIX

Upgrade to 4.4.1 and apply Patch Level 3 for a full fix.

> **IMPORTANT:** The patch cannot differentiate whether pre-existing invitations with EAR requirements set to **no** were defaulted to **no** from the upgrade to Faspex 4.4 or intentionally set to **no** by a user. If you have invitations that must be set to **no**, you must reissue those invitations.


### Patch Level 2 Fixes
| Jira Issue | Description                                                                                                             |
| ---------- | ----------------------------------------------------------------------------------------------------------------------- |
| FASPX-1779 | Faspex URLs generated using Inbox.Atom use final source share directory instead of the storage share directory.                              |
| FASPX-1778 | Not able to update Faspex package via API after package send.                                                           |
| FASPX-1783 | The pagination for `/api/users` endpoint does not return the correct results when the `page_num` value exceeds the page count. |

### Patch Level 1 Fixes

| Jira Issue | Description
| -------- | --------
| FASPX-1773 | Stats Collector logs show unnecessary information.
| FASPX-1772 | Creating users using the /user endpoint requires true and false Boolean values for can_send_normal_packages, can_send_to_external_email, andcan_send_to_all_faspex_users fields.
| FASPX-1770 | User created using the SDK does not inherit server default settings.
| FASPX-1388 | Implemented NoMgmtPortFiles in SOAP payload for remote source transfers.

See the included API reference included in the patch folder (open `IBM_Aspera_Faspex_4.4.1_PL3_api_reference/index.html` in your browser). 

## PATCH INSTRUCTIONS

### Applying the patch for Linux systems:
1. Download the patch file (`IBM_Aspera_Faspex_4.4.1_Linux_Windows_Patch_Level_3.zip`) and unzip it.

2. Make sure to back-up all the files in the faspex folder (``/opt/aspera/faspex/``).

3. Run the following command to replace existing files with patch files:

    ```$ /bin/cp -r patch_path/ IBM_Aspera_Faspex_4.4.1_Linux_Windows_Patch_Level_3/* /opt/aspera/faspex/```

4. Change ownership of the `/opt/aspera/faspex` folder to the `faspex` group and `faspex` user:

     ```
     cd /opt/aspera/faspex
     chown -R faspex:faspex *
     ```

5. Restart Faspex service:

    ```
    asctl faspex:restart
    ```
    
6. Run the following command to get updated database schema:

    ```
    asctl faspex:migrate_database
    ```


### Applying the patch for Windows systems:
1. Download the patch file (`IBM_Aspera_Faspex_4.4.1_Linux_Windows_Patch_Level_3.zip`) and unzip it.

2. Make sure to back-up all the files in the Faspex folder (`C:\Program Files\Aspera\Faspex\`).

3. Stop all Faspex services:

    a. Go to **Control Panel > Administrative Tools > Services**.

    b. For every service with Aspera Faspex in the name, right-click on the service and select Stop from the drop-down menu.

4. Replace existing files by copying patch files to appropriate directories in the Faspex folder (`C:\Program Files\Aspera\Faspex\`).

5. Restart all Faspex services:

    a. Go to **Control Panel > Administrative Tools > Services**.

    b. For every service with Aspera Faspex in the name, right-click on the service and select **Start** from the drop-down menu.

6. Run the following command to get updated database schema:

    ```
    asctl faspex:migrate_database
    ```


    
 
© IBM Aspera. Copyright IBM Corp. 2009, 2020

